/******************************************************************************
Project: QTexEngine
License: GNU GPL Version 3 (see LICENSE)
Copyright (C) by the authors:
    2024 Konstantin Kholostov <k.kholostov@fz-juelich.de>
Description: Compatibility layer for different Qt versions
 ******************************************************************************/

#ifndef QTEXENGINE_COMPAT_H
#define QTEXENGINE_COMPAT_H


#include <QTextStream>


namespace Qt
{
#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
    extern QString::SplitBehavior SkipEmptyParts;
#endif
} // namespace Qt


#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
class QStringConverter
{
  public:
    enum Encoding {
        Utf8,
    };

    static const char *codec(QStringConverter::Encoding encoding)
    {
        switch (encoding)
        {
            case Utf8:
                return "UTF-8";
            default:
                return "";
        }
    }
};
#endif


class CompatTextStream: public QTextStream
{
  public:
    using QTextStream::QTextStream;

#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
    void setEncoding(QStringConverter::Encoding encoding)
    {
        setCodec(QStringConverter::codec(encoding));
    }
#endif
};

#endif //QTEXENGINE_COMPAT_H
